@@ -29,7 +29,7 @@ namespace KIMAP
 {
 
 class Session;
-struct Message;
+struct Response;
 class LoginJobPrivate;
 
 class KIMAP_EXPORT LoginJob : public Job
@@ -66,7 +66,7 @@ public:
     };
 
     explicit LoginJob(Session *session);
-    virtual ~LoginJob();
+    ~LoginJob() override;
 
     QString userName() const;
     void setUserName(const QString &userName);
@@ -121,9 +121,9 @@ public:
     void setAuthenticationMode(AuthenticationMode mode);
 
 protected:
-    void doStart() Q_DECL_OVERRIDE;
-    void handleResponse(const Message &response) Q_DECL_OVERRIDE;
-    void connectionLost() Q_DECL_OVERRIDE;
+    void doStart() override;
+    void handleResponse(const Response &response) override;
+    void connectionLost() override;
 
 private:
     Q_PRIVATE_SLOT(d_func(), void sslResponse(bool))
